==> haskell-tasty-expected-failure-0.11.1.1-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-expected-failure.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-expected-failure
version: 0.11.1.1
id: tasty-expected-failure-0.11.1.1-n3dGMOL881HOMGrw8aAuc
key: tasty-expected-failure-0.11.1.1-n3dGMOL881HOMGrw8aAuc
license: MIT
copyright: 2015 Joachim Breitner
maintainer: mail@joachim-breitner.de
author: Joachim Breitner
homepage: http://github.com/nomeata/tasty-expected-failure
synopsis: Mark tasty tests as failure expected
description:
    With the function '\''Test.Tasty.ExpectedFailure.expectFail'\'' in the provided module
    "Test.Tasty.ExpectedFailure", you can mark that you expect test cases to fail,
    and not to pass.
    .
    This can for example be used for test-driven development: Create the tests,
    mark them with '\''Test.Tasty.ExpectedFailure.expectFail'\'', and you can still push
    to the main branch, without your continuous integration branch failing.
    .
    Once someone implements the feature or fixes the bug (maybe unknowingly), the
    test suite will tell him so, due to the now unexpectedly passing test, and he
    can remove the '\''Test.Tasty.ExpectedFailure.expectFail'\'' marker.
    .
    The module also provides '\''Test.Tasty.ExpectedFailure.ignoreTest'\'' to avoid
    running a test. Both funtions are implemented via the more general
    '\''Test.Tasty.ExpectedFailure.wrapTest'\'', which is also provided.
category: Testing
abi: 5e752558bfe17dee0416d365fc5379eb
exposed: True
exposed-modules:
    Test.Tasty.ExpectedFailure
import-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-expected-failure-0.11.1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-expected-failure-0.11.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/tasty-expected-failure-0.11.1.1
hs-libraries: HStasty-expected-failure-0.11.1.1-n3dGMOL881HOMGrw8aAuc
depends:
    base-4.11.1.0 tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    tasty-1.1.0.3-47QwUInRtOzF3zSlr6CCJg
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             tasty-1.1.0.3-47QwUInRtOzF3zSlr6CCJg=2e6555b026876c59a316d2124bf273ef
haddock-interfaces: /usr/share/doc/haskell-tasty-expected-failure/html/tasty-expected-failure.haddock
haddock-html: /usr/share/doc/haskell-tasty-expected-failure/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-expected-failure-0.11.1.1-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-expected-failure.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-expected-failure
version: 0.11.1.1
id: tasty-expected-failure-0.11.1.1-vjzm0zB2Zw1teGtsi3zxC
key: tasty-expected-failure-0.11.1.1-vjzm0zB2Zw1teGtsi3zxC
license: MIT
copyright: 2015 Joachim Breitner
maintainer: mail@joachim-breitner.de
author: Joachim Breitner
homepage: http://github.com/nomeata/tasty-expected-failure
synopsis: Mark tasty tests as failure expected
description:
    With the function '\''Test.Tasty.ExpectedFailure.expectFail'\'' in the provided module
    "Test.Tasty.ExpectedFailure", you can mark that you expect test cases to fail,
    and not to pass.
    .
    This can for example be used for test-driven development: Create the tests,
    mark them with '\''Test.Tasty.ExpectedFailure.expectFail'\'', and you can still push
    to the main branch, without your continuous integration branch failing.
    .
    Once someone implements the feature or fixes the bug (maybe unknowingly), the
    test suite will tell him so, due to the now unexpectedly passing test, and he
    can remove the '\''Test.Tasty.ExpectedFailure.expectFail'\'' marker.
    .
    The module also provides '\''Test.Tasty.ExpectedFailure.ignoreTest'\'' to avoid
    running a test. Both funtions are implemented via the more general
    '\''Test.Tasty.ExpectedFailure.wrapTest'\'', which is also provided.
category: Testing
abi: 64f4a9bb345b54f1571d36da547b2c68
exposed: True
exposed-modules:
    Test.Tasty.ExpectedFailure
import-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-expected-failure-0.11.1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-expected-failure-0.11.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/tasty-expected-failure-0.11.1.1
hs-libraries: HStasty-expected-failure-0.11.1.1-vjzm0zB2Zw1teGtsi3zxC
depends:
    base-4.11.1.0 tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    tasty-1.1.0.3-KUFSSP3U4ny9AQF2XUXxIK
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             tasty-1.1.0.3-KUFSSP3U4ny9AQF2XUXxIK=b3b38fe9dbf8881a7eed1fb4b5bf8074
haddock-interfaces: /usr/share/doc/haskell-tasty-expected-failure/html/tasty-expected-failure.haddock
haddock-html: /usr/share/doc/haskell-tasty-expected-failure/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
